<?php

namespace App\Http\Controllers;

use App\Models\product_color_setting_model;
use App\Models\product_size_setting_model;
use App\Models\product_model;
use App\Models\product_sub_category_model;
use App\Models\user_model;
use App\Models\product_category_setting_model;
use Illuminate\Http\Request;

class product_controller extends Controller
{
    protected $products;
    protected $users;
    protected $category;
    protected $sub_category;
    protected $color;
    protected $size;

    public function __construct(){
        $this->products = new product_model;
        $this->users = new user_model;
        $this->category = new product_category_setting_model;
        $this->sub_category = new product_sub_category_model;
        $this->color = new product_color_setting_model;
        $this->size = new product_size_setting_model;
    }

    public function product_list(){

        $login_user_id = session('userid');
        $login_user = $this->users->find($login_user_id);

        $products = $this->products->all();
        $data = compact('products','login_user');

        return view('products')->with($data);
    }

    public function add(){

        $login_user_id = session('userid');
        $login_user = $this->users->find($login_user_id);

        $url = route('product_form');
        $title = 'Add Product';
        $product = $this->products;

        $categories = $this->category->all();
        $sub_categories = $this->sub_category->all();
        $sizes = $this->size->all();
        $colors = $this->color->all();

        $data = compact('product','url','title','login_user','categories','sub_categories','sizes','colors');

        return view('product_form')->with($data);
    }

    public function store(Request $request)
    {
        $request->validate([
            'category' => 'required',
            'name' => 'required',
            'price' => 'required',
            'quantity' => 'required',
            'size' => 'required',
            'color' => 'required',
            'weight' => 'required',
            'composition' => 'required',
            'descryption' => 'required',
            'image' => 'required|image|mimes:jpg,jpeg,png,gif|max:2048',
        ]);

        $product = $this->products;

        // Handle image upload
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $extension = $image->getClientOriginalExtension();
            $filename = time() . '_' . $request->size . '.' . $extension;

            $image->move(public_path('/../../interior.images.local/'), $filename);

            // Save filename to DB
            $product->image = $filename;
        }

        // Save other fields
        $product->category = $request->category;
        $product->name = $request->name;
        $product->price = $request->price;
        $product->quantity = $request->quantity;
//        $product->size = $request->size;
        $product->size = implode(',', $request->size);

//        $product->color = $request->color;
        $product->color = implode(',', $request->color);
        $product->weight = $request->weight;
        $product->composition = $request->composition;
        $product->descryption = $request->descryption;
        $product->save();

        return redirect()->route('products')->with('success', 'Product added successfully!');
    }

    public function delete($id){

        $product = $this->products->find($id);

        if(!is_null($product)){

            $imagePath = public_path('img/' . $product->image);
            if (file_exists($imagePath)) {
                unlink($imagePath); // Delete the image file
            }

            $product->delete();
        }

        return redirect(route('products'));
    }

    public function edit($id){

        $login_user_id = session('userid');
        $login_user = $this->users->find($login_user_id);

        $product = $this->products->find($id);
        $categories = $this->category->all();
        $sub_categories = $this->sub_category->all();
        $sizes = $this->size->all();
        $colors = $this->color->all();


        if(is_null($product)){
            return redirect(route('products'));
        }else{

            $url = route('update_product', ['id' => $id]);
            $title = 'Edit Product';

            $data = compact('product','url','title','login_user','categories','sub_categories','sizes','colors');

            return view('product_form')->with($data);
        }
    }

    public function update($id, Request $request)
    {

        $request->validate([
            'category' => 'required',
            'name' => 'required',
            'price' => 'required',
            'quantity' => 'required',
            'size' => 'required',
            'color' => 'required',
            'weight' => 'required',
            'composition' => 'required',
            'descryption' => 'required',
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif|max:2048',
        ]);

        $product = $this->products->find($id);
        if (!$product) {
            return redirect()->route('products')->with('error', 'Product not found!');
        }

        if ($request->hasFile('image')) {

//            $oldImagePath = public_path('img/' . $product->image);
            $oldImagePath = public_path('/../../interior.images.local/' . $product->image);

            if (file_exists($oldImagePath)) {
                unlink($oldImagePath);
            }

            $image = $request->file('image');
            $extension = $image->getClientOriginalExtension();
            $filename = time() . '_' . $request->size . '.' . $extension;

//            $image->move(public_path('img'), $filename);
            $image->move(public_path('/../../interior.images.local/'), $filename);
            $product->image = $filename;
        }

        $product->category = $request->category;
        $product->name = $request->name;
        $product->price = $request->price;
        $product->quantity = $request->quantity;
//        $product->size = $request->size;
//        $product->color = $request->color;
        $product->size = implode(',', $request->size);
        $product->color = implode(',', $request->color);
        $product->weight = $request->weight;
        $product->composition = $request->composition;
        $product->descryption = $request->descryption;
        $product->save();

        return redirect()->route('products')->with('success', 'Product updated successfully!');

    }

    public function add_bulk_products(){

        $login_user_id = session('userid');
        $login_user = $this->users->find($login_user_id);

        $url = route('submit_bulk_products_form');
        $title = 'Add Bulk Products';

        $user = $this->users;

        $data = compact('user','url','title','login_user');

        return view('bulk_product_form')->with($data);
    }

//    public function store_bulk_products(Request $request)
//    {
//        $request->validate([
//            'products' => 'required|mimes:csv,txt,xlsx|max:20480',
//        ]);
//
//        $file = $request->file('products');
//
//        if (($handle = fopen($file->getRealPath(), 'r')) !== false) {
//
//            $header = null;
//            $batchData = [];
//
//            while (($row = fgetcsv($handle, 1000, ',')) !== false) {
//                if (!$header) {
//                    $header = array_map('trim', $row);
//                } else {
//                    if (count($header) !== count($row)) {
//                        continue;
//                    }
//
//                    $rowData = array_combine($header, $row);
//
//                    $batchData[] = [
//                        'image' => $rowData['image'] ?? null,
//                        'name' => $rowData['name'] ?? null,
//                        'quantity' => $rowData['quantity'] ?? 0,
//                        'size' => $rowData['size'] ?? null,
//                        'color' => $rowData['color'] ?? null,
//                        'weight' => $rowData['weight'] ?? null,
//                        'composition' => $rowData['composition'] ?? null,
//                        'price' => $rowData['price'] ?? 0,
//                        'descryption' => $rowData['description'] ?? null,
//                        'category' => $rowData['category'] ?? null,
//                    ];
//                }
//            }
//
//            fclose($handle);
//
//            $chunks = array_chunk($batchData, 500);
//
//            foreach ($chunks as $chunk) {
////                product_model::insert($chunk);
//            }
//
//            return redirect()->route('products')->with('success', 'Bulk products uploaded successfully!');
//        }
//
//        return redirect()->back()->with('error', 'Failed to upload file.');
//    }

    public function store_bulk_products(Request $request)
    {
        $request->validate([
            'products' => 'required|mimes:csv,txt,xlsx|max:20480',
        ]);

        $file = $request->file('products');

        if (($handle = fopen($file->getRealPath(), 'r')) !== false) {

            $header = null;
            $batchData = [];

            while (($row = fgetcsv($handle, 1000, ',')) !== false) {
                if (!$header) {
                    $header = array_map('trim', $row);
                } else {
                    if (count($header) !== count($row)) {
                        continue;
                    }

                    $rowData = array_combine($header, $row);

                    // Handling the sizes
                    $sizes = [];
                    if (!empty($rowData['size'])) {

                        $sizeRange = array_map('trim', explode('-', $rowData['size'])); // ['XS', '3XL']
                        $sizesList = $this->size->all(); // Collection from DB

                        // Convert to simple ordered array
                        $orderedSizes = $sizesList->pluck('size')->toArray(); // ['XS', 'S', 'M', 'L', 'XL', '2XL', '3XL']

                        // Find index of range start and end
                        $startIndex = array_search(strtoupper($sizeRange[0]), $orderedSizes);
                        $endIndex = array_search(strtoupper($sizeRange[1]), $orderedSizes);

                        // Ensure both start and end exist
                        if ($startIndex !== false && $endIndex !== false && $startIndex <= $endIndex) {
                            // Slice sizes in range
                            $matchedSizes = array_slice($orderedSizes, $startIndex, $endIndex - $startIndex + 1);

                            // Get IDs of those sizes
                            $matchedIds = $sizesList->whereIn('size', $matchedSizes)->pluck('id')->toArray();

                            // Create comma-separated string of IDs
                            $sizeIdString = implode(',', $matchedIds);
                        } else {
                            $sizeIdString = null; // fallback if size range invalid
                        }

                        $sizesQuery = product_size_setting_model::whereIn('size', array_map('strtoupper', $sizeRange))->get();

                        foreach ($sizesQuery as $size) {
                            $sizes[] = $size->id; // Collecting the IDs of matching sizes
                        }
                    }

                    // Handling the colors
                    $colors = [];
                    if (!empty($rowData['color'])) {
                        $colorList = explode(',', $rowData['color']); // Assuming colors are comma-separated

                        foreach ($colorList as $color) {
                            $color = trim($color);
                            $colorRecord = product_color_setting_model::firstOrCreate(
                                ['color' => strtolower($color)], // Create the color if it doesn't exist
                                ['color' => strtolower($color)]   // Insert with lowercase
                            );
                            $colors[] = $colorRecord->id; // Collecting the IDs of colors
                        }
                    }

                    $categoryIds = [];
                    if (!empty($rowData['category'])) {
                        $categoryNames = array_map('trim', explode(',', $rowData['category'])); // Assuming comma-separated categories
                        foreach ($categoryNames as $categoryName) {
                            $category = $this->category
                                ->whereRaw('LOWER(category) = ?', [strtolower($categoryName)])
                                ->first();

                            if ($category) {
                                $categoryIds[] = $category->id;
                            }
                        }
                    }
                    $categoryIdString = implode(',', $categoryIds);

                    $batchData[] = [
                        'image' => $rowData['image'] ?? null,
                        'name' => $rowData['name'] ?? null,
                        'quantity' => $rowData['quantity'] ?? 0,
//                        'size' => implode(',', $sizes), // Saving the sizes as a comma-separated string of IDs
                        'size' => $sizeIdString, // Saving the sizes as a comma-separated string of IDs
                        'color' => implode(',', $colors), // Saving the colors as a comma-separated string of IDs
                        'weight' => $rowData['weight'] ?? null,
                        'composition' => $rowData['composition'] ?? null,
                        'price' => $rowData['price'] ?? 0,
                        'descryption' => $rowData['description'] ?? null,
//                        'category' => $rowData['category'] ?? null,
                        'category' => $categoryIdString ?? null,
                    ];
                }
            }

            fclose($handle);

            $chunks = array_chunk($batchData, 500);

//            foreach ($chunks as $chunk) {
//                product_model::insert($chunk);
//            }

            foreach ($batchData as $data) {
                product_model::updateOrInsert(
                    ['name' => $data['name']], // Unique identifying condition
                    $data                      // Data to insert or update
                );
            }

            return redirect()->route('products')->with('success', 'Bulk products uploaded successfully!');
        }

        return redirect()->back()->with('error', 'Failed to upload file.');
    }


}
