<?php

namespace App\Http\Controllers;

use App\Models\user_model;
use App\Models\budget_model;
use App\Models\login_model;
use App\Models\email_model;
use Illuminate\Http\Request;

// For send Email To client
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Mail;
use App\Mail\user_mail;


class user_controller extends Controller
{
    protected $users;
    protected $budgets;
    protected $login;
    protected $email;

    public function __construct()
    {
        $this->users = new user_model;
        $this->budgets = new budget_model;
        $this->login = new login_model;
        $this->email = new email_model;
    }

    public function users_list(){

        $login_user_id = session('userid');
        $login_user = $this->users->find($login_user_id);

        $users = $this->users->all();

        $data = compact('users','login_user');
//        dd(session()->all());
        return view('users')->with($data);

    }

    public function add_user(){

        $login_user_id = session('userid');
        $login_user = $this->users->find($login_user_id);

        $url = route('user_form');
        $title = 'Add User';

        $user = $this->users;
        $budgets = $this->budgets->all();

        $data = compact('budgets','user','url','title','login_user');

        return view('user_form')->with($data);
    }

    public function store_user(Request $request){

        $request->validate([
            'name' => 'required',
            'email' => 'email|required|unique:users_table,email',
            'phone' => 'required|unique:users_table,phone',
            'password' => 'required|min:6',
            'role' => 'required',
            'status' => 'required',
            'budget' => 'required_without:custom_budget', // Ensure budget is required if custom_budget is not provided
            'custom_budget' => 'required_without:budget', // Ensure custom_budget is required if budget is not provided
        ]);

        $this->users->name = $request['name'];
        $this->users->email = $request['email'];
        $this->users->password = $request['password'];
        $this->users->phone = $request['phone'];
        $this->users->address = $request['address'];
        $this->users->role = $request['role'];
        $this->users->status = $request['status'];
        if($request['budget']){
            $this->users->budget = $request['budget'];
        }elseif($request['custom_budget']){
            $this->users->budget = $request['custom_budget'];
        }
        $this->users->save();

        $this->login->userid = $this->users->id;
        $this->login->name = $request['name'];
        $this->login->password = $request->password;
        $this->login->role = $request['role'];
        $this->login->status = $request['status'];
        $this->login->save();


        $email_configuration = $this->email->first();
        Config::set('mail.default', $email_configuration->mail_mailer);
        Config::set('mail.mailers.smtp.transport', 'smtp');
        Config::set('mail.mailers.smtp.host', $email_configuration->mail_host);
        Config::set('mail.mailers.smtp.port', $email_configuration->mail_port);
        Config::set('mail.mailers.smtp.username', $email_configuration->mail_username);
        Config::set('mail.mailers.smtp.password', $email_configuration->mail_password);
        Config::set('mail.mailers.smtp.encryption', $email_configuration->encryption);
        Config::set('mail.from.address', $email_configuration->mail_from_address);
        Config::set('mail.from.name', $email_configuration->mail_from_name);

//        $email = 'huzaifa.azeem@whmpress.com';
        Mail::to($this->users->email)->send(new user_mail($this->users, $email_configuration->mail_from_address, $email_configuration->mail_from_name));

//        Mail::to($this->users->email)->send(new UserWelcomeMail($this->users));
//        Mail::to($this->users->email)->send(new user_mail($this->users));

        return redirect(route('users'));
    }

    public function delete($id){

        $user = $this->users->find($id);
        if(!is_null($user)){
            $user->delete();
            $this->login->where('userid', $id)->delete();

        }

        return redirect(route('users'));
    }

    public function edit($id){

        $login_user_id = session('userid');
        $login_user = $this->users->find($login_user_id);

        $user = $this->users->find($id);
        $budgets = $this->budgets->all();


        if(is_null($user)){
            return redirect(route('users'));
        }else{

            $url = route('update_user', ['id' => $id]);
            $title = 'Edit User';

            $data = compact('budgets','user','url','title','login_user');

            return view('user_form')->with($data);
        }
    }

    public function update($id,Request $request){

        $request->validate([
            'name' => 'required',
            'email' => 'required|email|unique:users_table,email,' . $id,
            'phone' => 'required|unique:users_table,phone,' . $id,
            'password' => 'required|min:6',
            'role' => 'required',
            'status' => 'required',
            'budget' => 'required_without:custom_budget', // Ensure budget is required if custom_budget is not provided
            'custom_budget' => 'required_without:budget', // Ensure custom_budget is required if budget is not provided
        ]);

        $user = $this->users->find($id);
        if (!$user) {
            return redirect(route('users'));
        }

        $user->name = $request['name'];
        $user->email = $request['email'];
        $user->password = $request['password'];
        $user->phone = $request['phone'];
        $user->address = $request['address'];
        $user->role = $request['role'];
        $user->status = $request['status'];
        if($request['budget']){
            $user->budget = $request['budget'];
        }elseif($request['custom_budget']){
            $user->budget = $request['custom_budget'];
        }
        $user->save();


        $login = $this->login->where('userid', $user->id)->first();
        if (!$login) {
            $login = new login_model;
            $login->userid = $user->id;
        }

        $login->name = $request['name'];
        $login->password = $request['password'];
        $login->role = $request['role'];
        $login->status = $request['status'];
        $login->save();

        return redirect(route('users'));
    }

    public function add_bulk_users(){

        $login_user_id = session('userid');
        $login_user = $this->users->find($login_user_id);

        $url = route('submit_bulk_user_form');
        $title = 'Add Bulk Users';

        $user = $this->users;
        $budgets = $this->budgets->all();

        $data = compact('budgets','user','url','title','login_user');

        return view('bulk_user_form')->with($data);
    }

    public function store_bulk_users(Request $request)
    {
        $request->validate([
            'users' => 'required|mimes:csv,txt|max:20480',
        ]);

        $file = $request->file('users');

        if (($handle = fopen($file->getRealPath(), 'r')) !== false) {

            $header = null;
            $batchData = [];

            while (($row = fgetcsv($handle, 1000, ',')) !== false) {
                if (!$header) {
                    $header = $row;
                } else {
                    $rowData = array_combine($header, $row);

                    $batchData[] = [
                        'name' => $rowData['name'] ?? null,
                        'email' => $rowData['email'] ?? null,
//                        'password' => isset($rowData['password']) ? bcrypt($rowData['password']) : bcrypt('123456'), // encrypt password
                        'password' => $rowData['password'] ?? 123456,
                        'phone' => $rowData['phone'] ?? null,
                        'address' => $rowData['address'] ?? null,
                        'budget' => $rowData['budget'] ?? 0,
                        'role' => $rowData['role'] ?? 'user',
                        'status' => $rowData['status'] ?? 'active',
                    ];
                }
            }

            fclose($handle);

            $chunks = array_chunk($batchData, 500);

            foreach ($chunks as $chunk) {
                user_model::insert($chunk);
            }

            return redirect()->route('users')->with('success', 'Bulk users uploaded successfully!');
        }

        return redirect()->back()->with('error', 'Failed to upload file.');
    }

}
