@extends('layouts.main')

@push('nav_title')
    <a class="navbar-brand" href="{{route('users')}}">Send Email Form</a>
@endpush

@section('page_title')

    <h1>{{$title}}</h1>

@endsection

@section('side_bar')

    @include('layouts/side_bar')

@endsection

@section('profile')

    @include('layouts/profile')

@endsection

@section('main_div')

    <div class="container">
        <div class="tab-pane fade show active">
            <div class="card mt-24">
                <div class="card-header border-bottom">
                    <div class="card-body">
                        <form method="post" action="{{$url}}" enctype="multipart/form-data">
                            @csrf
                            <div class="mb-3">
                                <label for="mail_mailer" class="form-label mb-8 h6">Mail Mailer</label>
                                <input id="mail_mailer" type="text" class="form-control py-11" name="mail_mailer" value="{{ old('mail_mailer',$email_configuration->mail_mailer) }}">
                                <span class="text-danger">
                                    @error('mail_mailer') {{$message}} @enderror
                                </span>
                            </div>
                            <div class="mb-3">
                                <label for="mail_host" class="form-label mb-8 h6">Mail Host</label>
                                <input id="mail_host" type="text" class="form-control py-11" name="mail_host" value="{{ old('mail_host',$email_configuration->mail_host) }}">
                                <span class="text-danger">
                                    @error('mail_host') {{$message}} @enderror
                                </span>
                            </div>
                            <div class="mb-3">
                                <label for="mail_port" class="form-label mb-8 h6">Mail Port</label>
                                <input id="mail_port" type="text" class="form-control py-11" name="mail_port" value="{{ old('mail_port',$email_configuration->mail_port) }}">
                                <span class="text-danger">
                                    @error('mail_port') {{$message}} @enderror
                                </span>
                            </div>
                            <div class="mb-3">
                                <label for="mail_username" class="form-label mb-8 h6">Mail Username</label>
                                <input id="mail_username" type="text" class="form-control py-11" name="mail_username" value="{{ old('mail_username',$email_configuration->mail_username) }}">
                                <span class="text-danger">
                                    @error('mail_username') {{$message}} @enderror
                                </span>
                            </div>
                            <div class="mb-3">
                                <label for="mail_password" class="form-label mb-8 h6">Mail Password</label>
                                <input id="mail_password" type="text" class="form-control py-11" name="mail_password" value="{{ old('mail_password',$email_configuration->mail_password) }}">
                                <span class="text-danger">
                                    @error('mail_password') {{$message}} @enderror
                                </span>
                            </div>
                            <div class="mb-3">
                                <label for="mail_from_address" class="form-label mb-8 h6">Mail From Address</label>
                                <input id="mail_from_address" type="text" class="form-control py-11" name="mail_from_address" value="{{ old('mail_from_address',$email_configuration->mail_from_address) }}">
                                <span class="text-danger">
                                    @error('mail_from_address') {{$message}} @enderror
                                </span>
                            </div>
                            <div class="mb-3">
                                <label for="mail_from_name" class="form-label mb-8 h6">Mail From Name</label>
                                <input id="mail_from_name" type="text" class="form-control py-11" name="mail_from_name" value="{{ old('mail_from_name',$email_configuration->mail_from_name) }}">
                                <span class="text-danger">
                                    @error('mail_from_name') {{$message}} @enderror
                                </span>
                            </div>
                            <div class="mb-3">
                                <label for="encryption" class="form-label mb-8 h6">SSL Encryption</label>
                                <input id="encryption" type="text" class="form-control py-11" name="encryption" value="{{ old('encryption',$email_configuration->encryption) }}">
                                <span class="text-danger">
                                    @error('encryption') {{$message}} @enderror
                                </span>
                            </div>
                            <button class="btn btn-primary" type="submit">Confirm</button>
                        </form>

                    </div>
                </div>
            </div>
        </div>
    </div>

    <h3>Product Settings</h3>

    @include('layouts.product_settings')

    <div class="container">
        <h3>Project Color</h3>
        <div class="tab-pane fade show active">
            <div class="card mt-24">
                <div class="card-header border-bottom">
                    <div class="card-body">

                        <form method="post" action="{{route('save_project_color_settings')}}" enctype="multipart/form-data">
                            @csrf
                            <div class="form-group">
                                <label for="primary_color">Primary Color</label>
                                <input type="color" class="form-control" name="primary_color" id="primary_color"
                                       value="{{ $color['primary_color'] ?? '#000000' }}">
                            </div>

                            <div class="form-group">
                                <label for="secondary_color">Secondary Color</label>
                                <input type="color" class="form-control" name="secondary_color" id="secondary_color"
                                       value="{{ $color['secondary_color'] ?? '#000000' }}">
                            </div>

                            <button class="btn btn-primary" type="submit">Add</button>
                        </form>

                    </div>

                    <div class="color_list d-flex">
                        @foreach($colors as $color)
                            <div class="color mx-2" data-id="{{ $color->id }}">
                                Primary:
                                <span class="color_name">{{$color->primary_color}}</span>
                                Secondary:
                                <span class="color_name">{{$color->secondary_color}}</span>
                                <span class="color_icon">
                                    <i data-id="{{$color->id}}" class="fa-solid fa-circle-xmark del_color"></i>
                                </span>
                            </div>
                        @endforeach
                    </div>

                </div>
            </div>
        </div>
    </div>

    </div>

@endsection
