@extends('layouts.main')

@push('nav_title')
    <a class="navbar-brand" href="{{route('users')}}">User Form</a>
@endpush

@section('page_title')

    <h1>{{$title}}</h1>

    <a href="{{route('users')}}">
        <button class="btn btn-primary">Back</button>
    </a>

    <a href="{{route('bulk_users')}}">
        <button class="btn btn-secondary">Upload Bulk User</button>
    </a>


@endsection

@section('side_bar')

    @include('layouts/side_bar')

@endsection

@section('profile')

    @include('layouts/profile')

@endsection

@section('main_div')

    <div class="container">
        <div class="tab-pane fade show active">
            <div class="card mt-24">
                <div class="card-header border-bottom">
                    <div class="card-body">
                        <form action="{{$url}}" method="post">
                            @csrf

                            <x-form_component id="name" name="name" type="text" label="Name" :value="$user->name ?? '' "/>
                            <x-form_component id="email" name="email" type="email" label="Email" :value="$user->email ?? '' "/>
                            <x-form_component id="password" name="password" type="password" label="Password" :value="$user->password ?? '' "/>
                            <x-form_component id="phone" name="phone" type="text" label="Phone No" :value="$user->phone ?? '' "/>
                            <x-form_component id="address" name="address" type="text" label="Address" :value="$user->address ?? '' "/>

                            <div class="mb-3">
                                <label for="role" class="form-label mb-8 h6">Role</label>
                                <select id="role" name="role" class="form-select">
                                    <option value="" disabled selected>Select Role</option>
                                    <option value="admin" {{old('role', $user->role ?? '') == $user->role ? 'selected' : ''}}>Admin</option>
                                    <option value="user" {{old('role', $user->role ?? '') == $user->role ? 'selected' : ''}}>User</option>
                                </select>
                                <span class="text-danger">@error('role'){{$message}}@enderror</span>
                            </div>

                            <div class="mb-3">
                                <label for="status" class="form-label mb-8 h6">Status: {{$user->status}}</label>
                                <select id="status" name="status" class="form-select">
                                    <option value="" disabled selected>Select Status</option>
                                    <option value="active" {{ old('status', $user->status ?? '') == 'active' ? 'selected' : '' }}>Active</option>
                                    <option value="inactive" {{ old('status', $user->status ?? '') == 'inactive' ? 'selected' : '' }}>Inactive</option>
                                </select>
                                <span class="text-danger">@error('status'){{$message}}@enderror</span>
                            </div>

                            <div class="mb-3">
                                <label for="budget" class="form-label mb-8 h6">Budget</label>
                                <select id="budget" name="budget" class="form-select">
                                    <option value="" disabled selected>Select a budget</option>
                                    @foreach($budgets as $budget)
                                        <option value="{{$budget->price}}" {{ old('budget', $budget->price ?? '') == $user->budget ? 'selected' : '' }}>{{$budget->name}}</option>
                                    @endforeach
                                </select>

                                <span class="text-danger">
                                    @error('budget')
                                        {{$message}}
                                    @enderror
                                </span>
                            </div>

                            <x-form_component id="custom_budget" name="custom_budget" type="text" label="Custom Budget" :value="$user->custom_budget ?? '' "/>

                            <x-form_component id="custom_budget_checkbox" name="custom_budget_checkbox" type="checkbox" label="Enable Custom Budget" :value="$user->custom_budget_checkbox ?? ''" />


                            <button class="btn btn-primary" type="submit">Confirm</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>

    </div>

@endsection
