<?php

use App\Http\Controllers\ProfileController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\login_controller;
use App\Http\Controllers\dashboard;
use App\Http\Controllers\user_controller;
use App\Http\Controllers\product_controller;
use App\Http\Controllers\budget_controller;
use App\Http\Controllers\orders;
use App\Http\Controllers\email_controller;
use App\Http\Controllers\product_category_setting_controller;
use App\Http\Controllers\product_sub_category_setting_controller;
use App\Http\Controllers\product_size_setting_controller;
use App\Http\Controllers\product_color_setting_controller;


Route::get('/',[login_controller::class,'index'])->name('login');
Route::post('/login_form',[login_controller::class,'login'])->name('submit_login_form');
Route::get('/logout',[login_controller::class,'logout'])->name('logout');


Route::get('/color-settings.css', function () {
    $color = \App\Models\product_color_setting_model::first();

    $primaryColor = $color->primary_color ?? '#99FF02';
    $secondaryColor = $color->secondary_color ?? '#000000';

    return response("
        :root {
            --primary-color: $primaryColor;
            --secondary-color: $secondaryColor;
        }
    ")->header('Content-Type', 'text/css');
});


//--------------------------------------
Route::middleware(['checklogin'])->group(function () {

    Route::get('/dashboard', [dashboard::class, 'index'])->name('dashboard');


    //--------------------------------------

    Route::get('/orders', [orders::class, 'index'])->name('orders');

    Route::get('/order/delete/{id}', [orders::class, 'delete'])->name('delete_order');

    Route::get('/order/view/{id}', [orders::class, 'view_order'])->name('view_order');

    Route::post('/order/view', [orders::class, 'order_status'])->name('order_status_form');

    //--------------------------------------
    Route::get('/user', [user_controller::class, 'users_list'])->name('users');

    Route::get('/user_form', [user_controller::class, 'add_user'])->name('user_form');
    Route::post('/user_form', [user_controller::class, 'store_user'])->name('submit_user_form');

    Route::get('/user/delete/{id}', [user_controller::class, 'delete'])->name('delete_user');

    Route::get('/user/edit/{id}', [user_controller::class, 'edit'])->name('edit_user');
    Route::post('/user/update/{id}', [user_controller::class, 'update'])->name('update_user');

    Route::get('/user_bulk', [user_controller::class, 'add_bulk_users'])->name('bulk_users');
    Route::post('/user_bulk', [user_controller::class, 'store_bulk_users'])->name('submit_bulk_user_form');
    //---------------------------------------
    Route::get('/product', [product_controller::class, 'product_list'])->name('products');

    Route::get('/product_form', [product_controller::class, 'add'])->name('product_form');
    Route::post('/product_form', [product_controller::class, 'store'])->name('submit_product_form');

    Route::get('/product/delete/{id}', [product_controller::class, 'delete'])->name('delete_product');

    Route::get('/product/edit/{id}', [product_controller::class, 'edit'])->name('edit_product');
    Route::post('/product/update/{id}', [product_controller::class, 'update'])->name('update_product');

    Route::get('/product_bulk', [product_controller::class, 'add_bulk_products'])->name('bulk_products');
    Route::post('/product_bulk', [product_controller::class, 'store_bulk_products'])->name('submit_bulk_products_form');
    //----------------------------------------
    Route::get('/budget', [budget_controller::class, 'budget_list'])->name('budgets');

    Route::get('/budget_form', [budget_controller::class, 'add'])->name('budget_form');
    Route::post('/budget_form', [budget_controller::class, 'store'])->name('submit_budget_form');

    Route::get('/budget/delete/{id}', [budget_controller::class, 'delete'])->name('delete_budget');

    Route::get('/budget/edit/{id}', [budget_controller::class, 'edit'])->name('edit_budget');
    Route::post('/budget/update/{id}', [budget_controller::class, 'update'])->name('update_budget');

    //----------------------------------------
    Route::get('/settings', [email_controller::class, 'index'])->name('settings');
    Route::post('/settings', [email_controller::class, 'save_settings'])->name('save_settings');

    Route::post('/settings/product_category', [product_category_setting_controller::class, 'save_product_category_settings'])->name('save_product_category_settings');
    Route::get('/settings/del_product_category/{id}', [product_category_setting_controller::class, 'delete_product_category'])->name('del_product_category');

    Route::post('/settings/product_sub_category', [product_sub_category_setting_controller::class, 'save_product_sub_category_settings'])->name('save_product_sub_category_settings');
    Route::get('/settings/del_product_sub_category/{id}', [product_sub_category_setting_controller::class, 'delete_product_sub_category'])->name('del_product_sub_category');

    Route::post('/settings/product_color', [product_color_setting_controller::class, 'save_product_color_settings'])->name('save_product_color_settings');
    Route::get('/settings/del_product_color/{id}', [product_color_setting_controller::class, 'delete_product_color'])->name('delete_product_color');
    Route::post('/settings/project_color', [product_color_setting_controller::class, 'save_project_color_settings'])->name('save_project_color_settings');

    Route::post('/settings/product_size', [product_size_setting_controller::class, 'save_product_size_settings'])->name('save_product_size_settings');
    Route::get('/settings/del_product_size/{id}', [product_size_setting_controller::class, 'delete_product_size'])->name('delete_product_size');
});
